betty.ancestry.description module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.description module

Data types with human-readable description texts.

class betty.ancestry.description.HasDescription

  Bases: `LinkedDataDumpableJsonLdObject`

  A resource with a description.

  __init__(*args: Any, description: Mapping[str, str] | str | None = None, **kwargs: Any)
  description

    The human-readable description.

  async dump_linked_data(project: Project) → DumpMapping[Dump]

    Dump this instance to JSON-LD.